@@ -47,22 +47,22 @@
 #include <tqvbox.h>
 
 //KDE includes
-#include <kaboutdata.h>
-#include <kaccel.h>
-#include <kaction.h>
-#include <kapplication.h>
-#include <kconfigbase.h>
-#include <kdeversion.h>
-#include <kglobal.h>
+#include <tdeaboutdata.h>
+#include <tdeaccel.h>
+#include <tdeaction.h>
+#include <tdeapplication.h>
+#include <tdeconfigbase.h>
+#include <tdeversion.h>
+#include <tdeglobal.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kmenubar.h>
+#include <tdemenubar.h>
 #include <kstddirs.h>
 #include <kstdaction.h>
-#include <ktoolbar.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
-#include <kdeversion.h>
+#include <tdetoolbar.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
+#include <tdeversion.h>
 
 //Sword includes
 #include <swlog.h>
@@ -72,7 +72,7 @@ using namespace Profile;
 
 /**Initializes the view of this widget*/
 void BibleTime::initView() {
-	KStartupLogo::setStatusMessage(i18n("Creating BibleTime's GUI") + TQString("..."));
+	TDEStartupLogo::setStatusMessage(i18n("Creating BibleTime's GUI") + TQString("..."));
 
 	m_mainSplitter = new TQSplitter(this, "mainsplitter");
 	m_mainSplitter->setChildrenCollapsible(false);
@@ -96,23 +96,23 @@ void BibleTime::initView() {
 	m_mdi->setMinimumSize(100, 100);
 	m_mdi->setFocusPolicy(TQ_ClickFocus);
 
-	m_helpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData(), true, actionCollection());
+	m_helpMenu = new KHelpMenu(this, TDEGlobal::instance()->aboutData(), true, actionCollection());
 }
 
 /** Initializes the action objects of the GUI */
 void BibleTime::initActions() {
-	KStartupLogo::setStatusMessage(i18n("Initializing menu- and toolbars") + TQString("..."));
-	KAction* action = 0;
+	TDEStartupLogo::setStatusMessage(i18n("Initializing menu- and toolbars") + TQString("..."));
+	TDEAction* action = 0;
 
 	action = KStdAction::quit(TQT_TQOBJECT(kapp), TQT_SLOT( quit() ), actionCollection());
 	action->setToolTip( CResMgr::mainMenu::file::quit::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	action->plugAccel( accel() );
 	#endif
 
-	action = new KAction(i18n("Search in &open work(s)"),
+	action = new TDEAction(i18n("Search in &open work(s)"),
 						 CResMgr::mainMenu::mainIndex::search::icon,
 						 CResMgr::mainMenu::mainIndex::search::accel,
 						 TQT_TQOBJECT(this), TQT_SLOT(slotSearchModules()), actionCollection(),
@@ -120,12 +120,12 @@ void BibleTime::initActions() {
 						);
 	action->setToolTip( CResMgr::mainMenu::mainIndex::search::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	action->plugAccel( accel() );
 	#endif
 
-	action = new KAction(i18n("Search in standard &Bible"),
+	action = new TDEAction(i18n("Search in standard &Bible"),
 						 CResMgr::mainMenu::mainIndex::searchdefaultbible::icon,
 						 CResMgr::mainMenu::mainIndex::searchdefaultbible::accel,
 						 TQT_TQOBJECT(this), TQT_SLOT(slotSearchDefaultBible()), actionCollection(),
@@ -133,7 +133,7 @@ void BibleTime::initActions() {
 						);
 	action->setToolTip( CResMgr::mainMenu::mainIndex::searchdefaultbible::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	action->plugAccel( accel() );
 	#endif
@@ -141,32 +141,32 @@ void BibleTime::initActions() {
 	m_viewToolbar_action = KStdAction::showToolbar(TQT_TQOBJECT(this), TQT_SLOT( slotToggleToolbar() ), actionCollection());
 	m_viewToolbar_action->setToolTip( CResMgr::mainMenu::view::showToolBar::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_viewToolbar_action->plugAccel( accel() );
 	#endif
 
 
-	m_viewMainIndex_action = new KToggleAction(i18n("&Show bookshelf"),
+	m_viewMainIndex_action = new TDEToggleAction(i18n("&Show bookshelf"),
 							 CResMgr::mainMenu::view::showMainIndex::icon,
 							 CResMgr::mainMenu::view::showMainIndex::accel,
 							 TQT_TQOBJECT(this), TQT_SLOT(slotToggleMainIndex()), actionCollection(),
 							 CResMgr::mainMenu::view::showMainIndex::actionName);
 	m_viewMainIndex_action->setToolTip( CResMgr::mainMenu::view::showMainIndex::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_viewMainIndex_action->plugAccel( accel() );
 	#endif
 
-	m_viewInfoDisplay_action = new KToggleAction(i18n("Show &mag"),
+	m_viewInfoDisplay_action = new TDEToggleAction(i18n("Show &mag"),
 							   CResMgr::mainMenu::view::showInfoDisplay::icon,
 							   CResMgr::mainMenu::view::showInfoDisplay::accel,
 							   TQT_TQOBJECT(this), TQT_SLOT(slotToggleInfoDisplay()), actionCollection(),
 							   CResMgr::mainMenu::view::showInfoDisplay::actionName);
 	m_viewMainIndex_action->setToolTip( CResMgr::mainMenu::view::showInfoDisplay::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_viewInfoDisplay_action->plugAccel( accel() );
 	#endif
@@ -174,19 +174,19 @@ void BibleTime::initActions() {
 	action = KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT( slotSettingsOptions() ), actionCollection());
 	action->setToolTip( CResMgr::mainMenu::settings::optionsDialog::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	action->plugAccel( accel() );
 	#endif
 
-	action = new KAction(i18n("Bookshelf &Manager"),
+	action = new TDEAction(i18n("Bookshelf &Manager"),
 						 CResMgr::mainMenu::settings::swordSetupDialog::icon,
 						 CResMgr::mainMenu::settings::swordSetupDialog::accel,
 						 TQT_TQOBJECT(this), TQT_SLOT( slotSwordSetupDialog() ), actionCollection(),
 						 CResMgr::mainMenu::settings::swordSetupDialog::actionName
 						);
 	action->setToolTip( CResMgr::mainMenu::settings::swordSetupDialog::tooltip );
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	action->plugAccel( accel() );
 	#endif
@@ -200,18 +200,18 @@ void BibleTime::initActions() {
 	}
 	action = KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT( slotSettingsToolbar() ), actionCollection());
 	action->setToolTip( CResMgr::mainMenu::settings::editToolBar::tooltip );
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	action->plugAccel( accel() );
 	#endif
 
-	m_windowArrangementMode_action = new KActionMenu(i18n("&Arrangement mode"),
+	m_windowArrangementMode_action = new TDEActionMenu(i18n("&Arrangement mode"),
 							 CResMgr::mainMenu::window::arrangementMode::icon,
 							 actionCollection(),
 							 CResMgr::mainMenu::window::arrangementMode::actionName);
 	m_windowArrangementMode_action->setDelayed( false );
 
-	m_windowManualMode_action = new KToggleAction(i18n("&Manual mode"),
+	m_windowManualMode_action = new TDEToggleAction(i18n("&Manual mode"),
 								CResMgr::mainMenu::window::arrangementMode::manual::icon,
 								CResMgr::mainMenu::window::arrangementMode::manual::accel,
 								TQT_TQOBJECT(this), TQT_SLOT(slotManualArrangementMode()), actionCollection(),
@@ -220,7 +220,7 @@ void BibleTime::initActions() {
 	m_windowManualMode_action->setToolTip(
 		CResMgr::mainMenu::window::arrangementMode::manual::tooltip
 	);
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowManualMode_action->plugAccel( accel() );
 	#endif
@@ -228,7 +228,7 @@ void BibleTime::initActions() {
 	m_windowArrangementMode_action->insert( m_windowManualMode_action );
 
 
-	m_windowAutoTileVertical_action = new KToggleAction(i18n("Auto-tile &vertically"),
+	m_windowAutoTileVertical_action = new TDEToggleAction(i18n("Auto-tile &vertically"),
 									  CResMgr::mainMenu::window::arrangementMode::autoTileVertical::icon,
 									  CResMgr::mainMenu::window::arrangementMode::autoTileVertical::accel,
 									  TQT_TQOBJECT(this), TQT_SLOT(slotAutoTileVertical()), actionCollection(),
@@ -237,7 +237,7 @@ void BibleTime::initActions() {
 	m_windowAutoTileVertical_action->setToolTip(
 		CResMgr::mainMenu::window::arrangementMode::autoTileVertical::tooltip
 	);
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowAutoTileVertical_action->plugAccel( accel() );
 	#endif
@@ -245,7 +245,7 @@ void BibleTime::initActions() {
 	m_windowArrangementMode_action->insert( m_windowAutoTileVertical_action );
 
 
-	m_windowAutoTileHorizontal_action = new KToggleAction(i18n("Auto-tile &horizontally"),
+	m_windowAutoTileHorizontal_action = new TDEToggleAction(i18n("Auto-tile &horizontally"),
 										CResMgr::mainMenu::window::arrangementMode::autoTileHorizontal::icon,
 										CResMgr::mainMenu::window::arrangementMode::autoTileHorizontal::accel,
 										TQT_TQOBJECT(this), TQT_SLOT(slotAutoTileHorizontal()), actionCollection(),
@@ -254,7 +254,7 @@ void BibleTime::initActions() {
 	m_windowAutoTileHorizontal_action->setToolTip(
 		CResMgr::mainMenu::window::arrangementMode::autoTileHorizontal::tooltip
 	);
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowAutoTileHorizontal_action->plugAccel( accel() );
 	#endif
@@ -262,7 +262,7 @@ void BibleTime::initActions() {
 	m_windowArrangementMode_action->insert( m_windowAutoTileHorizontal_action );
 
 
-	m_windowAutoCascade_action  = new KToggleAction(i18n("Auto-&cascade"),
+	m_windowAutoCascade_action  = new TDEToggleAction(i18n("Auto-&cascade"),
 								  CResMgr::mainMenu::window::arrangementMode::autoCascade::icon,
 								  CResMgr::mainMenu::window::arrangementMode::autoCascade::accel,
 								  TQT_TQOBJECT(this), TQT_SLOT(slotAutoCascade()), actionCollection(),
@@ -271,14 +271,14 @@ void BibleTime::initActions() {
 	m_windowAutoCascade_action->setToolTip(
 		CResMgr::mainMenu::window::arrangementMode::autoCascade::tooltip
 	);
-	#if KDE_VERSION_MINOR < 1
-	//   qWarning("Plug accel");
+	#if TDE_VERSION_MINOR < 1
+	//   tqWarning("Plug accel");
 	m_windowAutoCascade_action->plugAccel( accel() );
 	#endif
 
 	m_windowArrangementMode_action->insert( m_windowAutoCascade_action );
 
-	m_windowCascade_action = new KAction(i18n("&Cascade"),
+	m_windowCascade_action = new TDEAction(i18n("&Cascade"),
 										 CResMgr::mainMenu::window::cascade::icon,
 										 CResMgr::mainMenu::window::cascade::accel,
 										 TQT_TQOBJECT(this), TQT_SLOT(slotCascade()), actionCollection(),
@@ -286,25 +286,25 @@ void BibleTime::initActions() {
 										);
 	m_windowCascade_action->setToolTip( CResMgr::mainMenu::window::cascade::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowCascade_action->plugAccel( accel() );
 	#endif
 
 
-	m_windowTileVertical_action = new KAction(i18n("Tile &vertically"),
+	m_windowTileVertical_action = new TDEAction(i18n("Tile &vertically"),
 								  CResMgr::mainMenu::window::tileVertical::icon,
 								  CResMgr::mainMenu::window::tileVertical::accel,
 								  TQT_TQOBJECT(this), TQT_SLOT(slotTileVertical()), actionCollection(),
 								  CResMgr::mainMenu::window::tileVertical::actionName
 											 );
 	m_windowTileVertical_action->setToolTip( CResMgr::mainMenu::window::tileVertical::tooltip );
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowTileVertical_action->plugAccel( accel() );
 	#endif
 
-	m_windowTileHorizontal_action = new KAction(i18n("Tile &horizontally"),
+	m_windowTileHorizontal_action = new TDEAction(i18n("Tile &horizontally"),
 									CResMgr::mainMenu::window::tileHorizontal::icon,
 									CResMgr::mainMenu::window::tileHorizontal::accel,
 									TQT_TQOBJECT(this), TQT_SLOT(slotTileHorizontal()), actionCollection(),
@@ -312,76 +312,76 @@ void BibleTime::initActions() {
 											   );
 	m_windowTileHorizontal_action->setToolTip( CResMgr::mainMenu::window::tileHorizontal::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowTileHorizontal_action->plugAccel( accel() );
 	#endif
 
 
-	m_windowCloseAll_action = new KAction(i18n("Cl&ose all"),
+	m_windowCloseAll_action = new TDEAction(i18n("Cl&ose all"),
 										  CResMgr::mainMenu::window::closeAll::icon,
 										  CResMgr::mainMenu::window::closeAll::accel,
 										  TQT_TQOBJECT(m_mdi), TQT_SLOT(deleteAll()), actionCollection(),
 										  CResMgr::mainMenu::window::closeAll::actionName
 										 );
 	m_windowCloseAll_action->setToolTip( CResMgr::mainMenu::window::closeAll::tooltip );
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowCloseAll_action->plugAccel( accel() );
 	#endif
 
 
-	m_windowSaveProfile_action = new KActionMenu(i18n("&Save session"),
+	m_windowSaveProfile_action = new TDEActionMenu(i18n("&Save session"),
 								 CResMgr::mainMenu::window::saveProfile::icon,
 								 actionCollection(),
 								 CResMgr::mainMenu::window::saveProfile::actionName
 												);
 	m_windowSaveProfile_action->setToolTip( CResMgr::mainMenu::window::saveProfile::tooltip );
 	m_windowSaveProfile_action->setDelayed( false );
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowSaveProfile_action->plugAccel( accel() );
 	#endif
 
 
-	m_windowSaveToNewProfile_action = new KAction(i18n("Save as &new session"),
+	m_windowSaveToNewProfile_action = new TDEAction(i18n("Save as &new session"),
 									  CResMgr::mainMenu::window::saveToNewProfile::icon,
 									  CResMgr::mainMenu::window::saveToNewProfile::accel,
 									  TQT_TQOBJECT(this), TQT_SLOT(saveToNewProfile()), actionCollection(),
 									  CResMgr::mainMenu::window::saveToNewProfile::actionName
 												 );
 	m_windowSaveToNewProfile_action->setToolTip( CResMgr::mainMenu::window::saveToNewProfile::tooltip );
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowSaveToNewProfile_action->plugAccel( accel() );
 	#endif
 
 
-	m_windowLoadProfile_action = new KActionMenu(i18n("&Load session"),
+	m_windowLoadProfile_action = new TDEActionMenu(i18n("&Load session"),
 								 CResMgr::mainMenu::window::loadProfile::icon,
 								 actionCollection(),
 								 CResMgr::mainMenu::window::loadProfile::actionName
 												);
 	m_windowLoadProfile_action->setToolTip(	CResMgr::mainMenu::window::loadProfile::tooltip	);
 	m_windowLoadProfile_action->setDelayed( false );
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowLoadProfile_action->plugAccel( accel() );
 	#endif
 
-	m_windowDeleteProfile_action = new KActionMenu(i18n("&Delete session"),
+	m_windowDeleteProfile_action = new TDEActionMenu(i18n("&Delete session"),
 								   CResMgr::mainMenu::window::deleteProfile::icon,
 								   actionCollection(),
 								   CResMgr::mainMenu::window::deleteProfile::actionName
 												  );
 	m_windowLoadProfile_action->setToolTip( CResMgr::mainMenu::window::deleteProfile::tooltip );
 	m_windowLoadProfile_action->setDelayed( false );
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowDeleteProfile_action->plugAccel( accel() );
 	#endif
 
-	m_windowFullscreen_action = new KToggleAction(i18n("&Fullscreen mode"),
+	m_windowFullscreen_action = new TDEToggleAction(i18n("&Fullscreen mode"),
 								CResMgr::mainMenu::window::showFullscreen::icon,
 								CResMgr::mainMenu::window::showFullscreen::accel,
 								TQT_TQOBJECT(this), TQT_SLOT(toggleFullscreen()), actionCollection(),
@@ -389,15 +389,15 @@ void BibleTime::initActions() {
 												 );
 	m_windowFullscreen_action->setToolTip( CResMgr::mainMenu::window::showFullscreen::tooltip );
 	m_windowFullscreen_action->setShortcutConfigurable(true);
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	m_windowFullscreen_action->plugAccel( accel() );
 	#endif
 
 	//connect the profile popups to the right slots
-	KPopupMenu* loadPopup = m_windowLoadProfile_action->popupMenu();
-	KPopupMenu* savePopup = m_windowSaveProfile_action->popupMenu();
-	KPopupMenu* deletePopup = m_windowDeleteProfile_action->popupMenu();
+	TDEPopupMenu* loadPopup = m_windowLoadProfile_action->popupMenu();
+	TDEPopupMenu* savePopup = m_windowSaveProfile_action->popupMenu();
+	TDEPopupMenu* deletePopup = m_windowDeleteProfile_action->popupMenu();
 
 	connect(loadPopup, TQT_SIGNAL(activated(int)), TQT_SLOT(loadProfile(int)));
 	connect(savePopup, TQT_SIGNAL(activated(int)), TQT_SLOT(saveProfile(int)));
@@ -410,7 +410,7 @@ void BibleTime::initActions() {
 		(actionCollection()->action(KStdAction::stdName(KStdAction::HelpContents)) );
 	}
 
-	action = new KAction(i18n("&Handbook"),
+	action = new TDEAction(i18n("&Handbook"),
 						 CResMgr::mainMenu::help::handbook::icon,
 						 CResMgr::mainMenu::help::handbook::accel,
 						 TQT_TQOBJECT(this), TQT_SLOT(openOnlineHelp_Handbook()), actionCollection(),
@@ -418,12 +418,12 @@ void BibleTime::initActions() {
 						);
 	action->setToolTip( CResMgr::mainMenu::help::handbook::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	action->plugAccel( accel() );
 	#endif
 
-	action = new KAction(i18n("&Bible Study Howto"),
+	action = new TDEAction(i18n("&Bible Study Howto"),
 						 CResMgr::mainMenu::help::bibleStudyHowTo::icon,
 						 CResMgr::mainMenu::help::bibleStudyHowTo::accel,
 						 TQT_TQOBJECT(this), TQT_SLOT(openOnlineHelp_Howto()), actionCollection(),
@@ -431,13 +431,13 @@ void BibleTime::initActions() {
 						);
 	action->setToolTip( CResMgr::mainMenu::help::bibleStudyHowTo::tooltip );
 
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	action->plugAccel( accel() );
 	#endif
 
 	if ( actionCollection()->action( KStdAction::stdName( KStdAction::WhatsThis ) ) ) {  //delete "What's this" action if KDE created it already
-		KAction* action = actionCollection()->action(KStdAction::stdName( KStdAction::WhatsThis ));
+		TDEAction* action = actionCollection()->action(KStdAction::stdName( KStdAction::WhatsThis ));
 		actionCollection()->remove
 		( action );
 	}
@@ -449,19 +449,19 @@ void BibleTime::initActions() {
 	}
 	action = KStdAction::reportBug(m_helpMenu, TQT_SLOT(reportBug()), actionCollection());
 	action->setToolTip(CResMgr::mainMenu::help::bugreport::tooltip);
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	action->plugAccel( accel() );
 	#endif
 
-	action = new KAction(i18n("&Daily tip"),
+	action = new TDEAction(i18n("&Daily tip"),
 						 CResMgr::mainMenu::help::dailyTip::icon,
 						 CResMgr::mainMenu::help::dailyTip::accel,
 						 TQT_TQOBJECT(this), TQT_SLOT(slotHelpTipOfDay()), actionCollection(),
 						 CResMgr::mainMenu::help::dailyTip::actionName
 						);
 	action->setToolTip(CResMgr::mainMenu::help::dailyTip::tooltip);
-	#if KDE_VERSION_MINOR < 1
+	#if TDE_VERSION_MINOR < 1
 
 	action->plugAccel( accel() );
 	#endif
@@ -501,7 +501,7 @@ void BibleTime::initConnections() {
 				this, TQT_SLOT(slotWindowMenuAboutToShow()));
 	}
 	else {
-		qWarning("Main window: can't find window menu");
+		tqWarning("Main window: can't find window menu");
 	}
 
 
@@ -518,7 +518,7 @@ void BibleTime::initConnections() {
 
 /** Initializes the backend */
 void BibleTime::initBackends() {
-	KStartupLogo::setStatusMessage(i18n("Initializing Sword") + TQString("..."));
+	TDEStartupLogo::setStatusMessage(i18n("Initializing Sword") + TQString("..."));
 
 	StringMgr::setSystemStringMgr( new BTStringMgr() );
 	SWLog::getSystemLog()->setLogLevel(1);
@@ -540,7 +540,7 @@ void BibleTime::initBackends() {
 		switch (errorCode) {
 			case CSwordBackend::NoSwordConfig: //mods.d or mods.conf missing
 			{
-				KStartupLogo::hideSplash();
+				TDEStartupLogo::hideSplash();
 				BookshelfManager::CSwordSetupDialog dlg;
 				dlg.showPart( BookshelfManager::CSwordSetupDialog::Sword );
 				dlg.exec();
@@ -549,7 +549,7 @@ void BibleTime::initBackends() {
 
 			case CSwordBackend::NoModules: //no modules installed, but config exists
 			{
-				KStartupLogo::hideSplash();
+				TDEStartupLogo::hideSplash();
 				BookshelfManager::CSwordSetupDialog dlg;
 				dlg.showPart( BookshelfManager::CSwordSetupDialog::Install );
 				dlg.exec();
@@ -558,7 +558,7 @@ void BibleTime::initBackends() {
 
 			default: //unknown error
 			{
-				KStartupLogo::hideSplash();
+				TDEStartupLogo::hideSplash();
 				BookshelfManager::CSwordSetupDialog dlg;
 				dlg.showPart( BookshelfManager::CSwordSetupDialog::Sword );
 				dlg.exec();
@@ -567,7 +567,7 @@ void BibleTime::initBackends() {
 		}
 	}
 
-	KStartupLogo::setStatusMessage(i18n("Checking indices") + TQString("..."));
+	TDEStartupLogo::setStatusMessage(i18n("Checking indices") + TQString("..."));
 	//This function will 
 	// - delete all orphaned indexes (no module present) if autoDeleteOrphanedIndices is true
 	// - delete all indices of modules where hasIndex() returns false
@@ -586,11 +586,11 @@ void BibleTime::applyProfileSettings( CProfile* p ) {
 		//first Main Window state
 		m_windowFullscreen_action->setChecked( p->fullscreen() );  //set the fullscreen button state
 		toggleFullscreen(); //either showFullscreen or showNormal
-		if (p->maximized()) KMainWindow::showMaximized(); //if maximized, then also call showMaximized
+		if (p->maximized()) TDEMainWindow::showMaximized(); //if maximized, then also call showMaximized
 	
 		//Then Main Window geometry
-		KMainWindow::resize( p->geometry().size() ); //Don't use KMainWindowInterface::resize
-		KMainWindow::move( p->geometry().topLeft() );//Don't use KMainWindowInterface::move
+		TDEMainWindow::resize( p->geometry().size() ); //Don't use TDEMainWindowInterface::resize
+		TDEMainWindow::move( p->geometry().topLeft() );//Don't use TDEMainWindowInterface::move
 }
 }
 
@@ -600,7 +600,7 @@ void BibleTime::storeProfileSettings( CProfile* p ) {
 	if (!p || !m_windowFullscreen_action) return;
 	
 	p->setFullscreen( m_windowFullscreen_action->isChecked() );
-	p->setMaximized( this->KMainWindow::isMaximized() );
+	p->setMaximized( this->TDEMainWindow::isMaximized() );
 
 	TQRect geometry;
 	geometry.setTopLeft(pos());
